@@ -55,3 +55,9 @@ def test_json_search_filtered():
     assert 'json' in response['content-type']
     info = simplejson.loads(content)
     assert len(info) == 30
+
+def test_funky_encoding():
+    http = httplib2.Http()
+    response, content = http.request(
+            'http://our_test_domain:8001/search?q=title:\"\xd3ptica%20electromagn\xe9tica\"')
+    assert response['status'] == '400', content
